'''OpenGL extension MESA.window_pos

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_MESA_window_pos'
_DEPRECATED = False

glWindowPos2dMESA = platform.createExtensionFunction( 
'glWindowPos2dMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,),
doc='glWindowPos2dMESA(GLdouble(x), GLdouble(y)) -> None',
argNames=('x','y',),
deprecated=_DEPRECATED,
)

glWindowPos2dvMESA = platform.createExtensionFunction( 
'glWindowPos2dvMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glWindowPos2dvMESA(GLdoubleArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos2fMESA = platform.createExtensionFunction( 
'glWindowPos2fMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,),
doc='glWindowPos2fMESA(GLfloat(x), GLfloat(y)) -> None',
argNames=('x','y',),
deprecated=_DEPRECATED,
)

glWindowPos2fvMESA = platform.createExtensionFunction( 
'glWindowPos2fvMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glWindowPos2fvMESA(GLfloatArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos2iMESA = platform.createExtensionFunction( 
'glWindowPos2iMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,),
doc='glWindowPos2iMESA(GLint(x), GLint(y)) -> None',
argNames=('x','y',),
deprecated=_DEPRECATED,
)

glWindowPos2ivMESA = platform.createExtensionFunction( 
'glWindowPos2ivMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLintArray,),
doc='glWindowPos2ivMESA(GLintArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos2sMESA = platform.createExtensionFunction( 
'glWindowPos2sMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLshort,constants.GLshort,),
doc='glWindowPos2sMESA(GLshort(x), GLshort(y)) -> None',
argNames=('x','y',),
deprecated=_DEPRECATED,
)

glWindowPos2svMESA = platform.createExtensionFunction( 
'glWindowPos2svMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLshortArray,),
doc='glWindowPos2svMESA(GLshortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos3dMESA = platform.createExtensionFunction( 
'glWindowPos3dMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glWindowPos3dMESA(GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('x','y','z',),
deprecated=_DEPRECATED,
)

glWindowPos3dvMESA = platform.createExtensionFunction( 
'glWindowPos3dvMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glWindowPos3dvMESA(GLdoubleArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos3fMESA = platform.createExtensionFunction( 
'glWindowPos3fMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glWindowPos3fMESA(GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('x','y','z',),
deprecated=_DEPRECATED,
)

glWindowPos3fvMESA = platform.createExtensionFunction( 
'glWindowPos3fvMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glWindowPos3fvMESA(GLfloatArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos3iMESA = platform.createExtensionFunction( 
'glWindowPos3iMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,),
doc='glWindowPos3iMESA(GLint(x), GLint(y), GLint(z)) -> None',
argNames=('x','y','z',),
deprecated=_DEPRECATED,
)

glWindowPos3ivMESA = platform.createExtensionFunction( 
'glWindowPos3ivMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLintArray,),
doc='glWindowPos3ivMESA(GLintArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos3sMESA = platform.createExtensionFunction( 
'glWindowPos3sMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glWindowPos3sMESA(GLshort(x), GLshort(y), GLshort(z)) -> None',
argNames=('x','y','z',),
deprecated=_DEPRECATED,
)

glWindowPos3svMESA = platform.createExtensionFunction( 
'glWindowPos3svMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLshortArray,),
doc='glWindowPos3svMESA(GLshortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos4dMESA = platform.createExtensionFunction( 
'glWindowPos4dMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glWindowPos4dMESA(GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w)) -> None',
argNames=('x','y','z','w',),
deprecated=_DEPRECATED,
)

glWindowPos4dvMESA = platform.createExtensionFunction( 
'glWindowPos4dvMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glWindowPos4dvMESA(GLdoubleArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos4fMESA = platform.createExtensionFunction( 
'glWindowPos4fMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glWindowPos4fMESA(GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('x','y','z','w',),
deprecated=_DEPRECATED,
)

glWindowPos4fvMESA = platform.createExtensionFunction( 
'glWindowPos4fvMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glWindowPos4fvMESA(GLfloatArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos4iMESA = platform.createExtensionFunction( 
'glWindowPos4iMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glWindowPos4iMESA(GLint(x), GLint(y), GLint(z), GLint(w)) -> None',
argNames=('x','y','z','w',),
deprecated=_DEPRECATED,
)

glWindowPos4ivMESA = platform.createExtensionFunction( 
'glWindowPos4ivMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLintArray,),
doc='glWindowPos4ivMESA(GLintArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glWindowPos4sMESA = platform.createExtensionFunction( 
'glWindowPos4sMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLshort,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glWindowPos4sMESA(GLshort(x), GLshort(y), GLshort(z), GLshort(w)) -> None',
argNames=('x','y','z','w',),
deprecated=_DEPRECATED,
)

glWindowPos4svMESA = platform.createExtensionFunction( 
'glWindowPos4svMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLshortArray,),
doc='glWindowPos4svMESA(GLshortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)


def glInitWindowPosMESA():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.fragment_lighting

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_fragment_lighting'
_DEPRECATED = False
GL_FRAGMENT_LIGHTING_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHTING_SGIX', 0x8400 )
GL_FRAGMENT_COLOR_MATERIAL_SGIX = constant.Constant( 'GL_FRAGMENT_COLOR_MATERIAL_SGIX', 0x8401 )
GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX = constant.Constant( 'GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX', 0x8402 )
GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX = constant.Constant( 'GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX', 0x8403 )
GL_MAX_FRAGMENT_LIGHTS_SGIX = constant.Constant( 'GL_MAX_FRAGMENT_LIGHTS_SGIX', 0x8404 )
GL_MAX_ACTIVE_LIGHTS_SGIX = constant.Constant( 'GL_MAX_ACTIVE_LIGHTS_SGIX', 0x8405 )
GL_CURRENT_RASTER_NORMAL_SGIX = constant.Constant( 'GL_CURRENT_RASTER_NORMAL_SGIX', 0x8406 )
GL_LIGHT_ENV_MODE_SGIX = constant.Constant( 'GL_LIGHT_ENV_MODE_SGIX', 0x8407 )
GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX', 0x8408 )
GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX', 0x8409 )
GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX', 0x840A )
GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX', 0x840B )
GL_FRAGMENT_LIGHT0_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT0_SGIX', 0x840C )
GL_FRAGMENT_LIGHT1_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT1_SGIX', 0x840D )
GL_FRAGMENT_LIGHT2_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT2_SGIX', 0x840E )
GL_FRAGMENT_LIGHT3_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT3_SGIX', 0x840F )
GL_FRAGMENT_LIGHT4_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT4_SGIX', 0x8410 )
GL_FRAGMENT_LIGHT5_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT5_SGIX', 0x8411 )
GL_FRAGMENT_LIGHT6_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT6_SGIX', 0x8412 )
GL_FRAGMENT_LIGHT7_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT7_SGIX', 0x8413 )
glFragmentColorMaterialSGIX = platform.createExtensionFunction( 
'glFragmentColorMaterialSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glFragmentColorMaterialSGIX(GLenum(face), GLenum(mode)) -> None',
argNames=('face','mode',),
deprecated=_DEPRECATED,
)

glFragmentLightfSGIX = platform.createExtensionFunction( 
'glFragmentLightfSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glFragmentLightfSGIX(GLenum(light), GLenum(pname), GLfloat(param)) -> None',
argNames=('light','pname','param',),
deprecated=_DEPRECATED,
)

glFragmentLightfvSGIX = platform.createExtensionFunction( 
'glFragmentLightfvSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glFragmentLightfvSGIX(GLenum(light), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('light','pname','params',),
deprecated=_DEPRECATED,
)

glFragmentLightiSGIX = platform.createExtensionFunction( 
'glFragmentLightiSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,),
doc='glFragmentLightiSGIX(GLenum(light), GLenum(pname), GLint(param)) -> None',
argNames=('light','pname','param',),
deprecated=_DEPRECATED,
)

glFragmentLightivSGIX = platform.createExtensionFunction( 
'glFragmentLightivSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glFragmentLightivSGIX(GLenum(light), GLenum(pname), GLintArray(params)) -> None',
argNames=('light','pname','params',),
deprecated=_DEPRECATED,
)

glFragmentLightModelfSGIX = platform.createExtensionFunction( 
'glFragmentLightModelfSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,),
doc='glFragmentLightModelfSGIX(GLenum(pname), GLfloat(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glFragmentLightModelfvSGIX = platform.createExtensionFunction( 
'glFragmentLightModelfvSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glFragmentLightModelfvSGIX(GLenum(pname), GLfloatArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glFragmentLightModeliSGIX = platform.createExtensionFunction( 
'glFragmentLightModeliSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glFragmentLightModeliSGIX(GLenum(pname), GLint(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glFragmentLightModelivSGIX = platform.createExtensionFunction( 
'glFragmentLightModelivSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glFragmentLightModelivSGIX(GLenum(pname), GLintArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glFragmentMaterialfSGIX = platform.createExtensionFunction( 
'glFragmentMaterialfSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glFragmentMaterialfSGIX(GLenum(face), GLenum(pname), GLfloat(param)) -> None',
argNames=('face','pname','param',),
deprecated=_DEPRECATED,
)

glFragmentMaterialfvSGIX = platform.createExtensionFunction( 
'glFragmentMaterialfvSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glFragmentMaterialfvSGIX(GLenum(face), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('face','pname','params',),
deprecated=_DEPRECATED,
)

glFragmentMaterialiSGIX = platform.createExtensionFunction( 
'glFragmentMaterialiSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,),
doc='glFragmentMaterialiSGIX(GLenum(face), GLenum(pname), GLint(param)) -> None',
argNames=('face','pname','param',),
deprecated=_DEPRECATED,
)

glFragmentMaterialivSGIX = platform.createExtensionFunction( 
'glFragmentMaterialivSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glFragmentMaterialivSGIX(GLenum(face), GLenum(pname), GLintArray(params)) -> None',
argNames=('face','pname','params',),
deprecated=_DEPRECATED,
)

glGetFragmentLightfvSGIX = platform.createExtensionFunction( 
'glGetFragmentLightfvSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetFragmentLightfvSGIX(GLenum(light), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('light','pname','params',),
deprecated=_DEPRECATED,
)

glGetFragmentLightivSGIX = platform.createExtensionFunction( 
'glGetFragmentLightivSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetFragmentLightivSGIX(GLenum(light), GLenum(pname), GLintArray(params)) -> None',
argNames=('light','pname','params',),
deprecated=_DEPRECATED,
)

glGetFragmentMaterialfvSGIX = platform.createExtensionFunction( 
'glGetFragmentMaterialfvSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetFragmentMaterialfvSGIX(GLenum(face), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('face','pname','params',),
deprecated=_DEPRECATED,
)

glGetFragmentMaterialivSGIX = platform.createExtensionFunction( 
'glGetFragmentMaterialivSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetFragmentMaterialivSGIX(GLenum(face), GLenum(pname), GLintArray(params)) -> None',
argNames=('face','pname','params',),
deprecated=_DEPRECATED,
)

glLightEnviSGIX = platform.createExtensionFunction( 
'glLightEnviSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glLightEnviSGIX(GLenum(pname), GLint(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)


def glInitFragmentLightingSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""FreeGLUT extensions to the GLUT API

This module will provide the FreeGLUT extensions if they are available
from the GLUT module.  Note that any other implementation that also provides
these entry points will also retrieve the entry points with this module.
"""
# flags 'freeglut_ext.xml -l /usr/lib64/libglut.so -o freeglut_ext.py -v -kf'
from OpenGL import platform, arrays
from OpenGL.constants import *
from OpenGL import constant
FUNCTION_TYPE = platform.PLATFORM.functionTypeFor( platform.GLUT )
from OpenGL.GLUT import special

import ctypes
c_int = ctypes.c_int 
c_char_p = ctypes.c_char_p
c_ubyte = ctypes.c_ubyte
c_void_p = ctypes.c_void_p

GLUT_DEBUG = constant.Constant( 'GLUT_DEBUG', 0x0001 )
GLUT_FORWARD_COMPATIBLE = constant.Constant( 'GLUT_FORWARD_COMPATIBLE',  0x0002)

GLUT_ACTION_EXIT = constant.Constant( 'GLUT_ACTION_EXIT', 0 )
GLUT_ACTION_GLUTMAINLOOP_RETURNS = constant.Constant( 'GLUT_ACTION_GLUTMAINLOOP_RETURNS', 1 )
GLUT_ACTION_CONTINUE_EXECUTION = constant.Constant( 'GLUT_ACTION_CONTINUE_EXECUTION', 2 )

GLUT_INIT_MAJOR_VERSION = constant.Constant( 'GLUT_INIT_MAJOR_VERSION', 0x0200 )
GLUT_INIT_MINOR_VERSION = constant.Constant( 'GLUT_INIT_MINOR_VERSION', 0x0201 )
GLUT_INIT_FLAGS = constant.Constant( 'GLUT_INIT_FLAGS', 0x0202 )

GLUT_CREATE_NEW_CONTEXT = constant.Constant( 'GLUT_CREATE_NEW_CONTEXT', 0 )
GLUT_USE_CURRENT_CONTEXT = constant.Constant( 'GLUT_USE_CURRENT_CONTEXT', 1 )

GLUT_ACTION_ON_WINDOW_CLOSE = constant.Constant( 'GLUT_ACTION_ON_WINDOW_CLOSE', 0x01F9 )
GLUT_WINDOW_BORDER_WIDTH = constant.Constant( 'GLUT_WINDOW_BORDER_WIDTH', 0x01FA )
GLUT_WINDOW_HEADER_HEIGHT = constant.Constant( 'GLUT_USE_CURRENT_CONTEXT', 0x01FB )
#GLUT_VERSION = constant.Constant( 'GLUT_VERSION', 0x01FC )
GLUT_RENDERING_CONTEXT = constant.Constant( 'GLUT_RENDERING_CONTEXT', 0x01FD )

# /usr/include/GL/freeglut_ext.h 63
glutMainLoopEvent = platform.createBaseFunction( 
    'glutMainLoopEvent', dll=platform.GLUT, resultType=None, 
    argTypes=[],
    doc='glutMainLoopEvent(  ) -> None', 
    argNames=(),
)
# /usr/include/GL/freeglut_ext.h 64
glutLeaveMainLoop = platform.createBaseFunction( 
    'glutLeaveMainLoop', dll=platform.GLUT, resultType=None, 
    argTypes=[],
    doc='glutLeaveMainLoop(  ) -> None', 
    argNames=(),
)

# /usr/include/GL/freeglut_ext.h 69
##glutMouseWheelFunc = platform.createBaseFunction( 
##	'glutMouseWheelFunc', dll=platform.GLUT, resultType=None, 
##	argTypes=[FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)],
##	doc='glutMouseWheelFunc( FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)(callback) ) -> None', 
##	argNames=('callback',),
##)
glutMouseWheelFunc = special.GLUTCallback(
    'MouseWheel', (c_int, c_int, c_int, c_int,), ('wheel','direction','x','y'),
)


# /usr/include/GL/freeglut_ext.h 70
##glutCloseFunc = platform.createBaseFunction( 
##	'glutCloseFunc', dll=platform.GLUT, resultType=None, 
##	argTypes=[FUNCTION_TYPE(None)],
##	doc='glutCloseFunc( FUNCTION_TYPE(None)(callback) ) -> None', 
##	argNames=('callback',),
##)
glutCloseFunc = special.GLUTCallback(
    'Close', (), (),
)

# /usr/include/GL/freeglut_ext.h 71
##glutWMCloseFunc = platform.createBaseFunction( 
##	'glutWMCloseFunc', dll=platform.GLUT, resultType=None, 
##	argTypes=[FUNCTION_TYPE(None)],
##	doc='glutWMCloseFunc( FUNCTION_TYPE(None)(callback) ) -> None', 
##	argNames=('callback',),
##)
glutWMCloseFunc = special.GLUTCallback(
    'WMClose', (), (),
)

# /usr/include/GL/freeglut_ext.h 73
##glutMenuDestroyFunc = platform.createBaseFunction( 
##	'glutMenuDestroyFunc', dll=platform.GLUT, resultType=None, 
##	argTypes=[FUNCTION_TYPE(None)],
##	doc='glutMenuDestroyFunc( FUNCTION_TYPE(None)(callback) ) -> None', 
##	argNames=('callback',),
##)
glutMenuDestroyFunc = special.GLUTCallback(
    'MenuDestroy', (), (),
)

# /usr/include/GL/freeglut_ext.h 78
glutSetOption = platform.createBaseFunction( 
    'glutSetOption', dll=platform.GLUT, resultType=None, 
    argTypes=[GLenum, c_int],
    doc='glutSetOption( GLenum(option_flag), c_int(value) ) -> None', 
    argNames=('option_flag', 'value'),
)

# /usr/include/GL/freeglut_ext.h 80
glutGetWindowData = platform.createBaseFunction( 
    'glutGetWindowData', dll=platform.GLUT, resultType=c_void_p, 
    argTypes=[],
    doc='glutGetWindowData(  ) -> c_void_p', 
    argNames=(),
)

# /usr/include/GL/freeglut_ext.h 81
glutSetWindowData = platform.createBaseFunction( 
    'glutSetWindowData', dll=platform.GLUT, resultType=None, 
    argTypes=[c_void_p],
    doc='glutSetWindowData( c_void_p(data) ) -> None', 
    argNames=('data',),
)

# /usr/include/GL/freeglut_ext.h 82
glutGetMenuData = platform.createBaseFunction( 
    'glutGetMenuData', dll=platform.GLUT, resultType=c_void_p, 
    argTypes=[],
    doc='glutGetMenuData(  ) -> c_void_p', 
    argNames=(),
)

# /usr/include/GL/freeglut_ext.h 83
glutSetMenuData = platform.createBaseFunction( 
    'glutSetMenuData', dll=platform.GLUT, resultType=None, 
    argTypes=[c_void_p],
    doc='glutSetMenuData( c_void_p(data) ) -> None', 
    argNames=('data',),
)

# /usr/include/GL/freeglut_ext.h 88
glutBitmapHeight = platform.createBaseFunction( 
    'glutBitmapHeight', dll=platform.GLUT, resultType=c_int, 
    argTypes=[c_void_p],
    doc='glutBitmapHeight( c_void_p(font) ) -> c_int', 
    argNames=('font',),
)

# /usr/include/GL/freeglut_ext.h 89
glutStrokeHeight = platform.createBaseFunction( 
    'glutStrokeHeight', dll=platform.GLUT, resultType=GLfloat, 
    argTypes=[c_void_p],
    doc='glutStrokeHeight( c_void_p(font) ) -> GLfloat', 
    argNames=('font',),
)

# /usr/include/GL/freeglut_ext.h 90
glutBitmapString = platform.createBaseFunction( 
    'glutBitmapString', dll=platform.GLUT, resultType=None, 
    argTypes=[c_void_p, c_char_p],
    doc='glutBitmapString( c_void_p(font), POINTER(c_ubyte)(string) ) -> None', 
    argNames=('font', 'string'),
)
##glutBitmapString = platform.createBaseFunction( 
##	'glutBitmapString', dll=platform.GLUT, resultType=None, 
##	argTypes=[c_void_p, arrays.GLubyteArray],
##	doc='glutBitmapString( c_void_p(font), POINTER(c_ubyte)(string) ) -> None', 
##	argNames=('font', 'string'),
##)
##glutBitmapString = arrays.setInputArraySizeType(
##	glutBitmapString,
##	None, 
##	arrays.GLubyteArray, 
##	'string',
##)

# /usr/include/GL/freeglut_ext.h 91
glutStrokeString = platform.createBaseFunction( 
    'glutStrokeString', dll=platform.GLUT, resultType=None, 
    argTypes=[c_void_p, c_char_p],
    doc='glutStrokeString( c_void_p(font), POINTER(c_ubyte)(string) ) -> None', 
    argNames=('font', 'string'),
)
##glutStrokeString = platform.createBaseFunction( 
##	'glutStrokeString', dll=platform.GLUT, resultType=None, 
##	argTypes=[c_void_p, arrays.GLubyteArray],
##	doc='glutStrokeString( c_void_p(font), POINTER(c_ubyte)(string) ) -> None', 
##	argNames=('font', 'string'),
##)
##glutStrokeString = arrays.setInputArraySizeType(
##	glutStrokeString,
##	None, 
##	arrays.GLubyteArray, 
##	'string',
##)

# /usr/include/GL/freeglut_ext.h 96
glutWireRhombicDodecahedron = platform.createBaseFunction( 
    'glutWireRhombicDodecahedron', dll=platform.GLUT, resultType=None, 
    argTypes=[],
    doc='glutWireRhombicDodecahedron(  ) -> None', 
    argNames=(),
)

# /usr/include/GL/freeglut_ext.h 97
glutSolidRhombicDodecahedron = platform.createBaseFunction( 
    'glutSolidRhombicDodecahedron', dll=platform.GLUT, resultType=None, 
    argTypes=[],
    doc='glutSolidRhombicDodecahedron(  ) -> None', 
    argNames=(),
)

# /usr/include/GL/freeglut_ext.h 98
glutWireSierpinskiSponge = platform.createBaseFunction( 
    'glutWireSierpinskiSponge', dll=platform.GLUT, resultType=None, 
    argTypes=[c_int, arrays.GLdoubleArray, GLdouble],
    doc='glutWireSierpinskiSponge( c_int(num_levels), arrays.GLdoubleArray(offset), GLdouble(scale) ) -> None', 
    argNames=('num_levels', 'offset', 'scale'),
)

glutWireSierpinskiSponge = arrays.setInputArraySizeType(
    glutWireSierpinskiSponge,
    None, # XXX Could not determine size of argument offset for glutWireSierpinskiSponge arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'offset',
)

# /usr/include/GL/freeglut_ext.h 99
glutSolidSierpinskiSponge = platform.createBaseFunction( 
    'glutSolidSierpinskiSponge', dll=platform.GLUT, resultType=None, 
    argTypes=[c_int, arrays.GLdoubleArray, GLdouble],
    doc='glutSolidSierpinskiSponge( c_int(num_levels), arrays.GLdoubleArray(offset), GLdouble(scale) ) -> None', 
    argNames=('num_levels', 'offset', 'scale'),
)

glutSolidSierpinskiSponge = arrays.setInputArraySizeType(
    glutSolidSierpinskiSponge,
    None, # XXX Could not determine size of argument offset for glutSolidSierpinskiSponge arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'offset',
)

# /usr/include/GL/freeglut_ext.h 100
glutWireCylinder = platform.createBaseFunction( 
    'glutWireCylinder', dll=platform.GLUT, resultType=None, 
    argTypes=[GLdouble, GLdouble, GLint, GLint],
    doc='glutWireCylinder( GLdouble(radius), GLdouble(height), GLint(slices), GLint(stacks) ) -> None', 
    argNames=('radius', 'height', 'slices', 'stacks'),
)

# /usr/include/GL/freeglut_ext.h 101
glutSolidCylinder = platform.createBaseFunction( 
    'glutSolidCylinder', dll=platform.GLUT, resultType=None, 
    argTypes=[GLdouble, GLdouble, GLint, GLint],
    doc='glutSolidCylinder( GLdouble(radius), GLdouble(height), GLint(slices), GLint(stacks) ) -> None', 
    argNames=('radius', 'height', 'slices', 'stacks'),
)

# /usr/include/GL/freeglut_ext.h 106
glutGetProcAddress = platform.createBaseFunction( 
    'glutGetProcAddress', dll=platform.GLUT, resultType=c_void_p, 
    argTypes=[c_char_p],
    doc='glutGetProcAddress( STRING(procName) ) -> c_void_p', 
    argNames=('procName',),
)


'''OpenGL extension VERSION.GL_3_1

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_3_1'
_DEPRECATED = False
GL_SAMPLER_2D_RECT = constant.Constant( 'GL_SAMPLER_2D_RECT', 0x8B63 )
GL_SAMPLER_2D_RECT_SHADOW = constant.Constant( 'GL_SAMPLER_2D_RECT_SHADOW', 0x8B64 )
GL_SAMPLER_BUFFER = constant.Constant( 'GL_SAMPLER_BUFFER', 0x8DC2 )
GL_INT_SAMPLER_2D_RECT = constant.Constant( 'GL_INT_SAMPLER_2D_RECT', 0x8DCD )
GL_INT_SAMPLER_BUFFER = constant.Constant( 'GL_INT_SAMPLER_BUFFER', 0x8DD0 )
GL_UNSIGNED_INT_SAMPLER_2D_RECT = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_2D_RECT', 0x8DD5 )
GL_UNSIGNED_INT_SAMPLER_BUFFER = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_BUFFER', 0x8DD8 )
GL_TEXTURE_BUFFER = constant.Constant( 'GL_TEXTURE_BUFFER', 0x8C2A )
GL_MAX_TEXTURE_BUFFER_SIZE = constant.Constant( 'GL_MAX_TEXTURE_BUFFER_SIZE', 0x8C2B )
GL_TEXTURE_BINDING_BUFFER = constant.Constant( 'GL_TEXTURE_BINDING_BUFFER', 0x8C2C )
GL_TEXTURE_BUFFER_DATA_STORE_BINDING = constant.Constant( 'GL_TEXTURE_BUFFER_DATA_STORE_BINDING', 0x8C2D )
GL_TEXTURE_BUFFER_FORMAT = constant.Constant( 'GL_TEXTURE_BUFFER_FORMAT', 0x8C2E )
GL_TEXTURE_RECTANGLE = constant.Constant( 'GL_TEXTURE_RECTANGLE', 0x84F5 )
GL_TEXTURE_BINDING_RECTANGLE = constant.Constant( 'GL_TEXTURE_BINDING_RECTANGLE', 0x84F6 )
GL_PROXY_TEXTURE_RECTANGLE = constant.Constant( 'GL_PROXY_TEXTURE_RECTANGLE', 0x84F7 )
GL_MAX_RECTANGLE_TEXTURE_SIZE = constant.Constant( 'GL_MAX_RECTANGLE_TEXTURE_SIZE', 0x84F8 )
GL_RED_SNORM = constant.Constant( 'GL_RED_SNORM', 0x8F90 )
GL_RG_SNORM = constant.Constant( 'GL_RG_SNORM', 0x8F91 )
GL_RGB_SNORM = constant.Constant( 'GL_RGB_SNORM', 0x8F92 )
GL_RGBA_SNORM = constant.Constant( 'GL_RGBA_SNORM', 0x8F93 )
GL_R8_SNORM = constant.Constant( 'GL_R8_SNORM', 0x8F94 )
GL_RG8_SNORM = constant.Constant( 'GL_RG8_SNORM', 0x8F95 )
GL_RGB8_SNORM = constant.Constant( 'GL_RGB8_SNORM', 0x8F96 )
GL_RGBA8_SNORM = constant.Constant( 'GL_RGBA8_SNORM', 0x8F97 )
GL_R16_SNORM = constant.Constant( 'GL_R16_SNORM', 0x8F98 )
GL_RG16_SNORM = constant.Constant( 'GL_RG16_SNORM', 0x8F99 )
GL_RGB16_SNORM = constant.Constant( 'GL_RGB16_SNORM', 0x8F9A )
GL_RGBA16_SNORM = constant.Constant( 'GL_RGBA16_SNORM', 0x8F9B )
GL_SIGNED_NORMALIZED = constant.Constant( 'GL_SIGNED_NORMALIZED', 0x8F9C )
GL_PRIMITIVE_RESTART = constant.Constant( 'GL_PRIMITIVE_RESTART', 0x8F9D )
GL_PRIMITIVE_RESTART_INDEX = constant.Constant( 'GL_PRIMITIVE_RESTART_INDEX', 0x8F9E )
glDrawArraysInstanced = platform.createExtensionFunction( 
'glDrawArraysInstanced',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glDrawArraysInstanced(GLenum(mode), GLint(first), GLsizei(count), GLsizei(primcount)) -> None',
argNames=('mode','first','count','primcount',),
deprecated=_DEPRECATED,
)

glDrawElementsInstanced = platform.createExtensionFunction( 
'glDrawElementsInstanced',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLenum,ctypes.c_void_p,constants.GLsizei,),
doc='glDrawElementsInstanced(GLenum(mode), GLsizei(count), GLenum(type), c_void_p(indices), GLsizei(primcount)) -> None',
argNames=('mode','count','type','indices','primcount',),
deprecated=_DEPRECATED,
)

glTexBuffer = platform.createExtensionFunction( 
'glTexBuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glTexBuffer(GLenum(target), GLenum(internalformat), GLuint(buffer)) -> None',
argNames=('target','internalformat','buffer',),
deprecated=_DEPRECATED,
)

glPrimitiveRestartIndex = platform.createExtensionFunction( 
'glPrimitiveRestartIndex',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glPrimitiveRestartIndex(GLuint(index)) -> None',
argNames=('index',),
deprecated=_DEPRECATED,
)




'''OpenGL extension IBM.texture_mirrored_repeat

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_IBM_texture_mirrored_repeat'
_DEPRECATED = False
GL_MIRRORED_REPEAT_IBM = constant.Constant( 'GL_MIRRORED_REPEAT_IBM', 0x8370 )


def glInitTextureMirroredRepeatIBM():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_cube_map_array

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_cube_map_array'
_DEPRECATED = False
GL_TEXTURE_CUBE_MAP_ARRAY = constant.Constant( 'GL_TEXTURE_CUBE_MAP_ARRAY', 0x9009 )
GL_TEXTURE_BINDING_CUBE_MAP_ARRAY = constant.Constant( 'GL_TEXTURE_BINDING_CUBE_MAP_ARRAY', 0x900A )
GL_PROXY_TEXTURE_CUBE_MAP_ARRAY = constant.Constant( 'GL_PROXY_TEXTURE_CUBE_MAP_ARRAY', 0x900B )
GL_SAMPLER_CUBE_MAP_ARRAY = constant.Constant( 'GL_SAMPLER_CUBE_MAP_ARRAY', 0x900C )
GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW = constant.Constant( 'GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW', 0x900D )
GL_INT_SAMPLER_CUBE_MAP_ARRAY = constant.Constant( 'GL_INT_SAMPLER_CUBE_MAP_ARRAY', 0x900E )
GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY', 0x900F )


def glInitTextureCubeMapArrayARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.multisample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_multisample'
_DEPRECATED = False
GL_MULTISAMPLE_EXT = constant.Constant( 'GL_MULTISAMPLE_EXT', 0x809D )
GL_SAMPLE_ALPHA_TO_MASK_EXT = constant.Constant( 'GL_SAMPLE_ALPHA_TO_MASK_EXT', 0x809E )
GL_SAMPLE_ALPHA_TO_ONE_EXT = constant.Constant( 'GL_SAMPLE_ALPHA_TO_ONE_EXT', 0x809F )
GL_SAMPLE_MASK_EXT = constant.Constant( 'GL_SAMPLE_MASK_EXT', 0x80A0 )
GL_1PASS_EXT = constant.Constant( 'GL_1PASS_EXT', 0x80A1 )
GL_2PASS_0_EXT = constant.Constant( 'GL_2PASS_0_EXT', 0x80A2 )
GL_2PASS_1_EXT = constant.Constant( 'GL_2PASS_1_EXT', 0x80A3 )
GL_4PASS_0_EXT = constant.Constant( 'GL_4PASS_0_EXT', 0x80A4 )
GL_4PASS_1_EXT = constant.Constant( 'GL_4PASS_1_EXT', 0x80A5 )
GL_4PASS_2_EXT = constant.Constant( 'GL_4PASS_2_EXT', 0x80A6 )
GL_4PASS_3_EXT = constant.Constant( 'GL_4PASS_3_EXT', 0x80A7 )
GL_SAMPLE_BUFFERS_EXT = constant.Constant( 'GL_SAMPLE_BUFFERS_EXT', 0x80A8 )
GL_SAMPLES_EXT = constant.Constant( 'GL_SAMPLES_EXT', 0x80A9 )
GL_SAMPLE_MASK_VALUE_EXT = constant.Constant( 'GL_SAMPLE_MASK_VALUE_EXT', 0x80AA )
GL_SAMPLE_MASK_INVERT_EXT = constant.Constant( 'GL_SAMPLE_MASK_INVERT_EXT', 0x80AB )
GL_SAMPLE_PATTERN_EXT = constant.Constant( 'GL_SAMPLE_PATTERN_EXT', 0x80AC )
GL_MULTISAMPLE_BIT_EXT = constant.Constant( 'GL_MULTISAMPLE_BIT_EXT', 0x20000000 )
glSampleMaskEXT = platform.createExtensionFunction( 
'glSampleMaskEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLclampf,constants.GLboolean,),
doc='glSampleMaskEXT(GLclampf(value), GLboolean(invert)) -> None',
argNames=('value','invert',),
deprecated=_DEPRECATED,
)

glSamplePatternEXT = platform.createExtensionFunction( 
'glSamplePatternEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glSamplePatternEXT(GLenum(pattern)) -> None',
argNames=('pattern',),
deprecated=_DEPRECATED,
)


def glInitMultisampleEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.copy_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_copy_texture'
_DEPRECATED = False

glCopyTexImage1DEXT = platform.createExtensionFunction( 
'glCopyTexImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLint,),
doc='glCopyTexImage1DEXT(GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLint(border)) -> None',
argNames=('target','level','internalformat','x','y','width','border',),
deprecated=_DEPRECATED,
)

glCopyTexImage2DEXT = platform.createExtensionFunction( 
'glCopyTexImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLint,),
doc='glCopyTexImage2DEXT(GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLsizei(height), GLint(border)) -> None',
argNames=('target','level','internalformat','x','y','width','height','border',),
deprecated=_DEPRECATED,
)

glCopyTexSubImage1DEXT = platform.createExtensionFunction( 
'glCopyTexSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,),
doc='glCopyTexSubImage1DEXT(GLenum(target), GLint(level), GLint(xoffset), GLint(x), GLint(y), GLsizei(width)) -> None',
argNames=('target','level','xoffset','x','y','width',),
deprecated=_DEPRECATED,
)

glCopyTexSubImage2DEXT = platform.createExtensionFunction( 
'glCopyTexSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyTexSubImage2DEXT(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('target','level','xoffset','yoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)

glCopyTexSubImage3DEXT = platform.createExtensionFunction( 
'glCopyTexSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyTexSubImage3DEXT(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('target','level','xoffset','yoffset','zoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)


def glInitCopyTextureEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.blend_minmax

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_blend_minmax'
_DEPRECATED = False
GL_FUNC_ADD_EXT = constant.Constant( 'GL_FUNC_ADD_EXT', 0x8006 )
GL_MIN_EXT = constant.Constant( 'GL_MIN_EXT', 0x8007 )
GL_MAX_EXT = constant.Constant( 'GL_MAX_EXT', 0x8008 )
GL_BLEND_EQUATION_EXT = constant.Constant( 'GL_BLEND_EQUATION_EXT', 0x8009 )
glget.addGLGetConstant( GL_BLEND_EQUATION_EXT, (1,) )
glBlendEquationEXT = platform.createExtensionFunction( 
'glBlendEquationEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glBlendEquationEXT(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)


def glInitBlendMinmaxEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.color_subtable

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.color_subtable to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows a portion of a color table to be redefined.
	If EXT_copy_texture is implemented, this extension also defines a
	method to load a portion of a color lookup table from the 
	framebuffer.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/color_subtable.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.color_subtable import *
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture_compression_rgtc

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_compression_rgtc'
_DEPRECATED = False
GL_COMPRESSED_RED_RGTC1_EXT = constant.Constant( 'GL_COMPRESSED_RED_RGTC1_EXT', 0x8DBB )
GL_COMPRESSED_SIGNED_RED_RGTC1_EXT = constant.Constant( 'GL_COMPRESSED_SIGNED_RED_RGTC1_EXT', 0x8DBC )
GL_COMPRESSED_RED_GREEN_RGTC2_EXT = constant.Constant( 'GL_COMPRESSED_RED_GREEN_RGTC2_EXT', 0x8DBD )
GL_COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT = constant.Constant( 'GL_COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT', 0x8DBE )


def glInitTextureCompressionRgtcEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.blend_equation_separate

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_blend_equation_separate'
_DEPRECATED = False
GL_BLEND_EQUATION_RGB_EXT = constant.Constant( 'GL_BLEND_EQUATION_RGB_EXT', 0x8009 )
GL_BLEND_EQUATION_ALPHA_EXT = constant.Constant( 'GL_BLEND_EQUATION_ALPHA_EXT', 0x883D )
glget.addGLGetConstant( GL_BLEND_EQUATION_ALPHA_EXT, (1,) )
glBlendEquationSeparateEXT = platform.createExtensionFunction( 
'glBlendEquationSeparateEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glBlendEquationSeparateEXT(GLenum(modeRGB), GLenum(modeAlpha)) -> None',
argNames=('modeRGB','modeAlpha',),
deprecated=_DEPRECATED,
)


def glInitBlendEquationSeparateEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension IBM.vertex_array_lists

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_IBM_vertex_array_lists'
_DEPRECATED = False

glColorPointerListIBM = platform.createExtensionFunction( 
'glColorPointerListIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLint,ctypes.POINTER(ctypes.c_void_p),constants.GLint,),
doc='glColorPointerListIBM(GLint(size), GLenum(type), GLint(stride), POINTER(ctypes.c_void_p)(pointer), GLint(ptrstride)) -> None',
argNames=('size','type','stride','pointer','ptrstride',),
deprecated=_DEPRECATED,
)

glSecondaryColorPointerListIBM = platform.createExtensionFunction( 
'glSecondaryColorPointerListIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLint,ctypes.POINTER(ctypes.c_void_p),constants.GLint,),
doc='glSecondaryColorPointerListIBM(GLint(size), GLenum(type), GLint(stride), POINTER(ctypes.c_void_p)(pointer), GLint(ptrstride)) -> None',
argNames=('size','type','stride','pointer','ptrstride',),
deprecated=_DEPRECATED,
)

glEdgeFlagPointerListIBM = platform.createExtensionFunction( 
'glEdgeFlagPointerListIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLbooleanArray,constants.GLint,),
doc='glEdgeFlagPointerListIBM(GLint(stride), GLbooleanArray(pointer), GLint(ptrstride)) -> None',
argNames=('stride','pointer','ptrstride',),
deprecated=_DEPRECATED,
)

glFogCoordPointerListIBM = platform.createExtensionFunction( 
'glFogCoordPointerListIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,ctypes.POINTER(ctypes.c_void_p),constants.GLint,),
doc='glFogCoordPointerListIBM(GLenum(type), GLint(stride), POINTER(ctypes.c_void_p)(pointer), GLint(ptrstride)) -> None',
argNames=('type','stride','pointer','ptrstride',),
deprecated=_DEPRECATED,
)

glIndexPointerListIBM = platform.createExtensionFunction( 
'glIndexPointerListIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,ctypes.POINTER(ctypes.c_void_p),constants.GLint,),
doc='glIndexPointerListIBM(GLenum(type), GLint(stride), POINTER(ctypes.c_void_p)(pointer), GLint(ptrstride)) -> None',
argNames=('type','stride','pointer','ptrstride',),
deprecated=_DEPRECATED,
)

glNormalPointerListIBM = platform.createExtensionFunction( 
'glNormalPointerListIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,ctypes.POINTER(ctypes.c_void_p),constants.GLint,),
doc='glNormalPointerListIBM(GLenum(type), GLint(stride), POINTER(ctypes.c_void_p)(pointer), GLint(ptrstride)) -> None',
argNames=('type','stride','pointer','ptrstride',),
deprecated=_DEPRECATED,
)

glTexCoordPointerListIBM = platform.createExtensionFunction( 
'glTexCoordPointerListIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLint,ctypes.POINTER(ctypes.c_void_p),constants.GLint,),
doc='glTexCoordPointerListIBM(GLint(size), GLenum(type), GLint(stride), POINTER(ctypes.c_void_p)(pointer), GLint(ptrstride)) -> None',
argNames=('size','type','stride','pointer','ptrstride',),
deprecated=_DEPRECATED,
)

glVertexPointerListIBM = platform.createExtensionFunction( 
'glVertexPointerListIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLint,ctypes.POINTER(ctypes.c_void_p),constants.GLint,),
doc='glVertexPointerListIBM(GLint(size), GLenum(type), GLint(stride), POINTER(ctypes.c_void_p)(pointer), GLint(ptrstride)) -> None',
argNames=('size','type','stride','pointer','ptrstride',),
deprecated=_DEPRECATED,
)


def glInitVertexArrayListsIBM():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_4

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_1_4 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_1_4.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.VERSION.GL_1_4 import *
### END AUTOGENERATED SECTION
from OpenGL.lazywrapper import lazy
from OpenGL.GL.pointers import glDrawElements
#glMultiDrawElements = wrapper.wrapper( glMultiDrawElements ).setPyConverter(
#	'indices', arrays.AsArrayOfType( 'indices', 'type' ),
#).setCResolver( 
#	'indices', arrays.ArrayDatatype.voidDataPointer ,
#).setPyConverter(
#	'count', arrays.AsArrayTyped( 'count', arrays.GLsizeiArray ),
#).setCResolver(
#	'count', arrays.ArrayDatatype.voidDataPointer ,
#)

@lazy( glMultiDrawElements )
def glMultiDrawElements(baseOperation, primtype, counts, typ, indices, primcount=None):
    """Currently glMultiDrawElements is not working in the wrapper 
    
    We are replacing the code with a sequence of glDrawElements calls
    as per the spec for the function.  Basically we'd spend more effort
    making an array of array pointers than we would creating a simple
    iteration in Python.
    """
    if primcount is not None:
        for i in xrange( primcount ):
            glDrawElements( primtype, counts[i], typ, indices[i] )
    else:
        for c,i in zip( counts, indices ):
            glDrawElements( primtype, c, typ, i )


'''OpenGL extension EXT.texture_cube_map

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_cube_map'
_DEPRECATED = False
GL_NORMAL_MAP_EXT = constant.Constant( 'GL_NORMAL_MAP_EXT', 0x8511 )
GL_REFLECTION_MAP_EXT = constant.Constant( 'GL_REFLECTION_MAP_EXT', 0x8512 )
GL_TEXTURE_CUBE_MAP_EXT = constant.Constant( 'GL_TEXTURE_CUBE_MAP_EXT', 0x8513 )
GL_TEXTURE_BINDING_CUBE_MAP_EXT = constant.Constant( 'GL_TEXTURE_BINDING_CUBE_MAP_EXT', 0x8514 )
GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT', 0x8515 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT', 0x8516 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT', 0x8517 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT', 0x8518 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT', 0x8519 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT', 0x851A )
GL_PROXY_TEXTURE_CUBE_MAP_EXT = constant.Constant( 'GL_PROXY_TEXTURE_CUBE_MAP_EXT', 0x851B )
GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT = constant.Constant( 'GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT', 0x851C )


def glInitTextureCubeMapEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.occlusion_query

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_occlusion_query'
_DEPRECATED = False
GL_PIXEL_COUNTER_BITS_NV = constant.Constant( 'GL_PIXEL_COUNTER_BITS_NV', 0x8864 )
glget.addGLGetConstant( GL_PIXEL_COUNTER_BITS_NV, (1,) )
GL_CURRENT_OCCLUSION_QUERY_ID_NV = constant.Constant( 'GL_CURRENT_OCCLUSION_QUERY_ID_NV', 0x8865 )
glget.addGLGetConstant( GL_CURRENT_OCCLUSION_QUERY_ID_NV, (1,) )
GL_PIXEL_COUNT_NV = constant.Constant( 'GL_PIXEL_COUNT_NV', 0x8866 )
GL_PIXEL_COUNT_AVAILABLE_NV = constant.Constant( 'GL_PIXEL_COUNT_AVAILABLE_NV', 0x8867 )
glGenOcclusionQueriesNV = platform.createExtensionFunction( 
'glGenOcclusionQueriesNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenOcclusionQueriesNV(GLsizei(n), GLuintArray(ids)) -> None',
argNames=('n','ids',),
deprecated=_DEPRECATED,
)

glDeleteOcclusionQueriesNV = platform.createExtensionFunction( 
'glDeleteOcclusionQueriesNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteOcclusionQueriesNV(GLsizei(n), GLuintArray(ids)) -> None',
argNames=('n','ids',),
deprecated=_DEPRECATED,
)

glIsOcclusionQueryNV = platform.createExtensionFunction( 
'glIsOcclusionQueryNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsOcclusionQueryNV(GLuint(id)) -> constants.GLboolean',
argNames=('id',),
deprecated=_DEPRECATED,
)

glBeginOcclusionQueryNV = platform.createExtensionFunction( 
'glBeginOcclusionQueryNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glBeginOcclusionQueryNV(GLuint(id)) -> None',
argNames=('id',),
deprecated=_DEPRECATED,
)

glEndOcclusionQueryNV = platform.createExtensionFunction( 
'glEndOcclusionQueryNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glEndOcclusionQueryNV() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glGetOcclusionQueryivNV = platform.createExtensionFunction( 
'glGetOcclusionQueryivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetOcclusionQueryivNV(GLuint(id), GLenum(pname), GLintArray(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)

glGetOcclusionQueryuivNV = platform.createExtensionFunction( 
'glGetOcclusionQueryuivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLuintArray,),
doc='glGetOcclusionQueryuivNV(GLuint(id), GLenum(pname), GLuintArray(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)


def glInitOcclusionQueryNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension APPLE.ycbcr_422

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_APPLE_ycbcr_422'
_DEPRECATED = False
GL_YCBCR_422_APPLE = constant.Constant( 'GL_YCBCR_422_APPLE', 0x85B9 )
GL_UNSIGNED_SHORT_8_8_APPLE = constant.Constant( 'GL_UNSIGNED_SHORT_8_8_APPLE', 0x85BA )
GL_UNSIGNED_SHORT_8_8_REV_APPLE = constant.Constant( 'GL_UNSIGNED_SHORT_8_8_REV_APPLE', 0x85BB )


def glInitYcbcr422APPLE():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""Refactored version of the opengl generator using ctypeslib
"""
try:
    from ctypeslib.codegen import codegenerator
    from ctypeslib import xml2py
except ImportError, err:
    try:
        from ctypes_codegen import codegenerator, xml2py
    except ImportError, err:
        from ctypes.wrap import codegenerator, xml2py
try:
    from cStringIO import StringIO
except ImportError, err:
    from StringIO import StringIO

import sys, logging
log = logging.getLogger( 'openglgenerator' )
import ctypes
from OpenGL.platform import GL, GLU, GLUT, GLE
from OpenGL import constant

def indent( code, indentation='\t' ):
    """Indent given code by given indentation"""
    lines = code.splitlines()
    return "\n".join( [ '%s%s'%(indentation,line) for line in lines] )

class OpenGLGenerator( codegenerator.Generator ):
    """Subclass of code generator providing PyOpenGL integration"""
    _super = codegenerator.Generator
    MODULE_HEADER = """from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL import constants as GLconstants
GLvoid = GLconstants.GLvoid
"""
    def defaultEmitters( cls ):
        """Produce the set of default emitter classes
        """
        return [
            OpenGLFunction(),
            OpenGLConstant(),
        ] + cls._super.defaultEmitters()
    def importAble( cls, name, value ):
        """Determine whether this name/object should be imported from known symbols"""
        return (
            isinstance( value, type ) or 
            isinstance( value, constant.Constant ) or 
            value.__class__.__name__.endswith( 'CFunctionType') # this should be available *somewhere*!
        )
    importAble = classmethod( importAble )

    def filter_items( self, items, expressions=None,symbols=None, types=None ):
        """Filter out PFN functions"""
        items = [
            i for i in items 
            # skip the pointer-to-function meta-types...
            if not getattr( i,'name','').startswith( 'PFN' )
        ]
        return self._super.filter_items( self, items, expressions=expressions, symbols=symbols, types=types )
    def get_sharedlib(self, dllname, cc):
        """Override so that all references to shared libraries go through "platform" module"""
        if dllname in ('libGL','GL','libGL.so.1'):
            return 'platform.GL'
        elif dllname in ('libGLU','GLU','libGLU.so.1'):
            return 'platform.GLU'
        elif dllname in ('libglut','glut','libglut.so.3'):
            return 'platform.GLUT'
        elif dllname in ('libgle','gle','libgle.so.3' ):
            return 'platform.GLE'
        else:
            raise NotImplementedError( """Haven't done %s yet!"""%(dllname) )
    def cmpitems( self, a, b ):
        """Dumb sorting helper to order by name instead of position"""
        try:
            return cmp( (a.name,getattr(a, "location", -1), a.__class__), (b.name,getattr(b, "location", 1),b.__class__))
        except (AttributeError,TypeError,ValueError), err:
            return cmp( a, b )

        

class OpenGLFunction( codegenerator.Function ):
    """Replaces the ctypes default code generator for functions"""
    TEMPLATE = """%(location)s%(name)s = platform.createBaseFunction( 
    %(name)r, dll=%(libname)s, resultType=%(returnType)s, 
    argTypes=[%(argTypes)s],
    doc=%(documentation)r, 
    argNames=%(argNames)r,
)
"""
    def emit(self, generator, func):
        """Produce a function via a call to platform-provided function"""
        result = []
        libname = self.libName( generator, func )
        if libname:
            self.increment()
            result.append( self.generateHeader( generator, func ))
            args = self.getArgs( generator, func )
            argTypes  = ",".join( args )
            argNames = self.getArgNames( generator, func )
            location = self.locationComment( generator, func )
            name = func.name
            returnType = generator.type_name(func.returns)

            documentation = self.documentFunction( generator, func )

            generator.names.add(func.name)
            result.append( self.TEMPLATE %locals() )
            return result
        elif not func.name.startswith( '__builtin_' ):
            log.warn( """Could not find DLL name for function: %r""", func.name )
            return ''

    def arrayTypeName( self, generator, argType ):
        """Retrieve the array type name for argType or None"""
        if generator.type_name(argType).startswith( 'POINTER' ):
            # side effect should be to make the type available,
            # but doesn't work with GLvoid
            typeName = generator.type_name(argType.typ)
            if self.CTYPE_TO_ARRAY_TYPE.has_key( typeName ):
                return 'arrays.%s'%(self.CTYPE_TO_ARRAY_TYPE[typeName])
            elif (typeName == 'GLvoid'):
                # normal to not have pointers to it...
                log.info( 'GLvoid pointer %r, using POINTER(%s)', typeName, typeName )
            else:
                log.warn( 'No mapping for %r, using POINTER(%s)', typeName, typeName )
        return None
    def getArgs( self, generator, func ):
        """Retrieve arg type-names for all arguments in function typedef"""
        return [
            self.arrayTypeName( generator, a ) or generator.type_name(a) 
            for a in func.iterArgTypes()
        ]
    def documentFunction( self, generator, func ):
        """Customisation point for documenting a given function"""
        args = self.getArgs(generator,func)
        argnames = self.getArgNames( generator, func )
        return str("%s( %s ) -> %s"%(
            func.name,
            ", ".join(
                [ '%s(%s)'%( name, typ) for (name,typ) in zip(args,argnames) ]
            ),
            generator.type_name(func.returns),
        ))
    SUFFIX_TO_ARRAY_DATATYPE = [
        ('ub','GLconstants.GL_UNSIGNED_BYTE'),
        ('us','GLconstants.GL_UNSIGNED_SHORT'),
        ('ui','GLconstants.GL_UNSIGNED_INT'),
        ('f','GLconstants.GL_FLOAT'),
        ('d','GLconstants.GL_DOUBLE'),
        ('i','GLconstants.GL_INT'),
        ('s','GLconstants.GL_SHORT'),
        ('b','GLconstants.GL_BYTE'),
    ]
    CTYPE_TO_ARRAY_TYPE = {
        'GLfloat': 'GLfloatArray',
        'float': 'GLfloatArray',
        'GLclampf': 'GLclampfArray',
        'GLdouble': 'GLdoubleArray',
        'double': 'GLdoubleArray',
        'int': 'GLintArray',
        'GLint': 'GLintArray',
        'GLuint': 'GLuintArray',
        'unsigned int':'GLuintArray',
        'unsigned char': 'GLbyteArray',
        'uint': 'GLuintArray',
        'GLshort': 'GLshortArray',
        'GLushort': 'GLushortArray',
        'short unsigned int':'GLushortArray',
        'GLubyte': 'GLubyteArray',
        'GLbyte': 'GLbyteArray',
        'char': 'GLbyteArray',
        'gleDouble': 'GLdoubleArray',
        # following should all have special sub-classes that enforce dimensions
        'gleDouble * 4': 'GLdoubleArray',
        'gleDouble * 3': 'GLdoubleArray',
        'gleDouble * 2': 'GLdoubleArray',
        'c_float * 3': 'GLfloatArray',
        'gleDouble * 3 * 2': 'GLdoubleArray',
    }

class OpenGLConstant( codegenerator.Variable ):
    """Override to produce OpenGL.constant.Constant instances"""
    TEMPLATE = """%(name)s = Constant( %(name)r, %(value)r)"""
    def emit( self, generator, typedef ):
        """Filter out constants that don't have all-uppercase names"""
        if typedef.name.upper() != typedef.name:
            return ""
        return super( OpenGLConstant, self ).emit( generator, typedef )

class OpenGLDecorator( OpenGLFunction ):
    """Produces decorated versions of the functions in a separate module
    
    This is passed in as an emitter for a separate pass, so that only the
    annotations get into the separate module.
    """
    def isPointer( self, generator, arg ):
        """Is given arg-type a pointer?"""
        return generator.type_name( arg ).startswith( 'POINTER' )
    def hasPointer( self, generator, args ):
        """Given set of arg-types, is one a pointer?"""
        return [ arg for arg in args if self.isPointer( generator, arg ) ]
    def emit( self, generator, func ):
        """Emit code to create a copy of the function with pointer-size annotations"""
        name = func.name 
        size = None 
        typ = None
        if not self.hasPointer( generator, func.iterArgTypes() ):
            return None
        libname = self.libName( generator, func )
        if not libname:
            return None
        base = name 
        if name.endswith( 'ARB' ):
            base = base[:-3]
        if base.endswith( 'v' ):
            base = base[:-1]
            found = 0
            for suffix,typ in self.SUFFIX_TO_ARRAY_DATATYPE:
                if base.endswith(suffix):
                    found = 1
                    base = base[:-len(suffix)]
                    try:
                        size = int(base[-1])
                    except ValueError, err:
                        size = None
                    break
        elif base[:-1].endswith( 'Matrix' ):
            # glLoadMatrix, glMultMatrix
            for suffix,typ in self.SUFFIX_TO_ARRAY_DATATYPE:
                if name.endswith( suffix ):
                    size = 16
                    break
        result = ''
        for index,(arg,argName) in enumerate( zip(func.iterArgTypes(),func.iterArgNames()) ):
            type = self.arrayTypeName( generator, arg )
            argName = str(argName )
            if type:
                generator.names.add(func.name)
            if result:
                previous = indent( result, '\t' )
            else:
                previous = '\traw.%(name)s'%locals()
            if type and size is None:
                # should only print this if it's a normal array type...
                result = """arrays.setInputArraySizeType(
%(previous)s,
    None, # XXX Could not determine size of argument %(argName)s for %(name)s %(type)s
    %(type)s, 
    %(argName)r,
)
"""%locals()
            elif type:
                result = """arrays.setInputArraySizeType(
%(previous)s,
    %(size)s,
    %(type)s,
    %(argName)r,
)
"""%locals()
        if result:
            return '%(name)s = %(result)s'%locals()
        return None
    

if __name__ == "__main__":
    import sys, logging
    logging.basicConfig()
    codegenerator.Generator = OpenGLGenerator
    sys.exit(xml2py.main())


'''OpenGL extension WIN.specular_fog

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_WIN_specular_fog'
_DEPRECATED = False
GL_FOG_SPECULAR_TEXTURE_WIN = constant.Constant( 'GL_FOG_SPECULAR_TEXTURE_WIN', 0x80EC )


def glInitSpecularFogWIN():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension HP.image_transform

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_HP_image_transform'
_DEPRECATED = False
GL_IMAGE_SCALE_X_HP = constant.Constant( 'GL_IMAGE_SCALE_X_HP', 0x8155 )
GL_IMAGE_SCALE_Y_HP = constant.Constant( 'GL_IMAGE_SCALE_Y_HP', 0x8156 )
GL_IMAGE_TRANSLATE_X_HP = constant.Constant( 'GL_IMAGE_TRANSLATE_X_HP', 0x8157 )
GL_IMAGE_TRANSLATE_Y_HP = constant.Constant( 'GL_IMAGE_TRANSLATE_Y_HP', 0x8158 )
GL_IMAGE_ROTATE_ANGLE_HP = constant.Constant( 'GL_IMAGE_ROTATE_ANGLE_HP', 0x8159 )
GL_IMAGE_ROTATE_ORIGIN_X_HP = constant.Constant( 'GL_IMAGE_ROTATE_ORIGIN_X_HP', 0x815A )
GL_IMAGE_ROTATE_ORIGIN_Y_HP = constant.Constant( 'GL_IMAGE_ROTATE_ORIGIN_Y_HP', 0x815B )
GL_IMAGE_MAG_FILTER_HP = constant.Constant( 'GL_IMAGE_MAG_FILTER_HP', 0x815C )
GL_IMAGE_MIN_FILTER_HP = constant.Constant( 'GL_IMAGE_MIN_FILTER_HP', 0x815D )
GL_IMAGE_CUBIC_WEIGHT_HP = constant.Constant( 'GL_IMAGE_CUBIC_WEIGHT_HP', 0x815E )
GL_CUBIC_HP = constant.Constant( 'GL_CUBIC_HP', 0x815F )
GL_AVERAGE_HP = constant.Constant( 'GL_AVERAGE_HP', 0x8160 )
GL_IMAGE_TRANSFORM_2D_HP = constant.Constant( 'GL_IMAGE_TRANSFORM_2D_HP', 0x8161 )
GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP = constant.Constant( 'GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP', 0x8162 )
GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP = constant.Constant( 'GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP', 0x8163 )
glImageTransformParameteriHP = platform.createExtensionFunction( 
'glImageTransformParameteriHP',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,),
doc='glImageTransformParameteriHP(GLenum(target), GLenum(pname), GLint(param)) -> None',
argNames=('target','pname','param',),
deprecated=_DEPRECATED,
)

glImageTransformParameterfHP = platform.createExtensionFunction( 
'glImageTransformParameterfHP',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glImageTransformParameterfHP(GLenum(target), GLenum(pname), GLfloat(param)) -> None',
argNames=('target','pname','param',),
deprecated=_DEPRECATED,
)

glImageTransformParameterivHP = platform.createExtensionFunction( 
'glImageTransformParameterivHP',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glImageTransformParameterivHP(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glImageTransformParameterfvHP = platform.createExtensionFunction( 
'glImageTransformParameterfvHP',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glImageTransformParameterfvHP(GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetImageTransformParameterivHP = platform.createExtensionFunction( 
'glGetImageTransformParameterivHP',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetImageTransformParameterivHP(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetImageTransformParameterfvHP = platform.createExtensionFunction( 
'glGetImageTransformParameterfvHP',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetImageTransformParameterfvHP(GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)


def glInitImageTransformHP():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""Test simple functions (i.e. no pointers involved)"""
from OpenGL.GL import *
from OpenGL.GLU import *
from OpenGL.GLUT import *
import time
start = time.time()

window = None

def drawText( value, x,y,  windowHeight, windowWidth, step = 18 ):
    """Draw the given text at given 2D position in window
    """
    glMatrixMode(GL_PROJECTION);
    # For some reason the GL_PROJECTION_MATRIX is overflowing with a single push!
    # glPushMatrix()
    matrix = glGetDouble( GL_PROJECTION_MATRIX )
    
    glLoadIdentity();
    glOrtho(0.0, windowHeight or 32, 0.0, windowWidth or 32, -1.0, 1.0)
    glMatrixMode(GL_MODELVIEW);
    glPushMatrix();
    glLoadIdentity();
    glRasterPos2i(x, y);
    lines = 0
    for character in value:
        if character == '\n':
            glRasterPos2i(x, y-(lines*18))
        else:
            glutBitmapCharacter(GLUT_BITMAP_HELVETICA_18, ord(character));
    glPopMatrix();
    glMatrixMode(GL_PROJECTION);
    # For some reason the GL_PROJECTION_MATRIX is overflowing with a single push!
    # glPopMatrix();
    glLoadMatrixd( matrix ) # should have un-decorated alias for this...
    
    glMatrixMode(GL_MODELVIEW);

def display():
    glutSetWindow(window);
    glClearColor (0.0, 0.0, (time.time()%1.0)/1.0, 0.0)
    glClear (GL_COLOR_BUFFER_BIT)
    drawText( 'hello', 20,20, size[0],size[1] )
    #glutBitmapCharacter( GLUT_BITMAP_8_BY_13, ord('a'))
    glutSolidTeapot( .2 )
    glFlush ()
    glutSwapBuffers()

size = (250,250)

def reshape( *args ):
    global size 
    size = args
    glViewport( *( (0,0)+args) )
    display()

def ontimer( *args ):
    print 'timer', args, '@time', time.time()-start
    glutTimerFunc( 1000, ontimer, 24 )

def idle():
    delta = time.time()-start
    if delta < 10:
        global size 
        x,y = size 
        if delta < 5:
            change = +1
        else:
            change = -1
        x = x-change
        y = y+change
        if x < 1:
            x = 1
        if y < 1:
            y = 1
        glutReshapeWindow( x, y )
        size = (x,y)
        glutSetWindow(window)
        glutPostRedisplay()
    else:
        glutDestroyWindow( window )
        print 'window destroyed'
        import sys
        sys.exit( 0 )

def printFunction( name ):
    def onevent( *args ):
        print '%s -> %s'%(name, ", ".join( [str(a) for a in args ]))
    return onevent



if __name__ == "__main__":
    import sys
    newArgv = glutInit(sys.argv)
    print 'newArguments', newArgv
    glutInitDisplayMode( GLUT_DOUBLE | GLUT_RGB )
    glutInitWindowSize(250, 250)
    glutInitWindowPosition(100, 100)
    window = glutCreateWindow("hello")
    print 'window', repr(window)
    glutDisplayFunc(display)
    glutReshapeFunc(reshape)
    glutMouseFunc(printFunction( 'Mouse' ))
    glutEntryFunc(printFunction( 'Entry' ))
    glutKeyboardFunc( printFunction( 'Keyboard' ))
    glutKeyboardUpFunc( printFunction( 'KeyboardUp' ))
    glutMotionFunc( printFunction( 'Motion' ))
    glutPassiveMotionFunc( printFunction( 'PassiveMotion' ))
    glutVisibilityFunc( printFunction( 'Visibility' ))
    glutWindowStatusFunc( printFunction( 'WindowStatus' ))
    glutSpecialFunc( printFunction( 'Special' ))
    glutSpecialUpFunc( printFunction( 'SpecialUp' ))
    glutTimerFunc( 1000, ontimer, 23 )
    
    glutIdleFunc( idle )
    glutMainLoop()


'''OpenGL extension EXT.framebuffer_object

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_framebuffer_object'
_DEPRECATED = False
GL_INVALID_FRAMEBUFFER_OPERATION_EXT = constant.Constant( 'GL_INVALID_FRAMEBUFFER_OPERATION_EXT', 0x506 )
GL_MAX_RENDERBUFFER_SIZE_EXT = constant.Constant( 'GL_MAX_RENDERBUFFER_SIZE_EXT', 0x84E8 )
glget.addGLGetConstant( GL_MAX_RENDERBUFFER_SIZE_EXT, (1,) )
GL_FRAMEBUFFER_BINDING_EXT = constant.Constant( 'GL_FRAMEBUFFER_BINDING_EXT', 0x8CA6 )
glget.addGLGetConstant( GL_FRAMEBUFFER_BINDING_EXT, (1,) )
GL_RENDERBUFFER_BINDING_EXT = constant.Constant( 'GL_RENDERBUFFER_BINDING_EXT', 0x8CA7 )
glget.addGLGetConstant( GL_RENDERBUFFER_BINDING_EXT, (1,) )
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT', 0x8CD0 )
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT', 0x8CD1 )
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT', 0x8CD2 )
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT', 0x8CD3 )
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT', 0x8CD4 )
GL_FRAMEBUFFER_COMPLETE_EXT = constant.Constant( 'GL_FRAMEBUFFER_COMPLETE_EXT', 0x8CD5 )
GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT', 0x8CD6 )
GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT', 0x8CD7 )
GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT', 0x8CD9 )
GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT', 0x8CDA )
GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT', 0x8CDB )
GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT', 0x8CDC )
GL_FRAMEBUFFER_UNSUPPORTED_EXT = constant.Constant( 'GL_FRAMEBUFFER_UNSUPPORTED_EXT', 0x8CDD )
GL_MAX_COLOR_ATTACHMENTS_EXT = constant.Constant( 'GL_MAX_COLOR_ATTACHMENTS_EXT', 0x8CDF )
glget.addGLGetConstant( GL_MAX_COLOR_ATTACHMENTS_EXT, (1,) )
GL_COLOR_ATTACHMENT0_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT0_EXT', 0x8CE0 )
GL_COLOR_ATTACHMENT1_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT1_EXT', 0x8CE1 )
GL_COLOR_ATTACHMENT2_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT2_EXT', 0x8CE2 )
GL_COLOR_ATTACHMENT3_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT3_EXT', 0x8CE3 )
GL_COLOR_ATTACHMENT4_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT4_EXT', 0x8CE4 )
GL_COLOR_ATTACHMENT5_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT5_EXT', 0x8CE5 )
GL_COLOR_ATTACHMENT6_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT6_EXT', 0x8CE6 )
GL_COLOR_ATTACHMENT7_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT7_EXT', 0x8CE7 )
GL_COLOR_ATTACHMENT8_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT8_EXT', 0x8CE8 )
GL_COLOR_ATTACHMENT9_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT9_EXT', 0x8CE9 )
GL_COLOR_ATTACHMENT10_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT10_EXT', 0x8CEA )
GL_COLOR_ATTACHMENT11_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT11_EXT', 0x8CEB )
GL_COLOR_ATTACHMENT12_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT12_EXT', 0x8CEC )
GL_COLOR_ATTACHMENT13_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT13_EXT', 0x8CED )
GL_COLOR_ATTACHMENT14_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT14_EXT', 0x8CEE )
GL_COLOR_ATTACHMENT15_EXT = constant.Constant( 'GL_COLOR_ATTACHMENT15_EXT', 0x8CEF )
GL_DEPTH_ATTACHMENT_EXT = constant.Constant( 'GL_DEPTH_ATTACHMENT_EXT', 0x8D00 )
GL_STENCIL_ATTACHMENT_EXT = constant.Constant( 'GL_STENCIL_ATTACHMENT_EXT', 0x8D20 )
GL_FRAMEBUFFER_EXT = constant.Constant( 'GL_FRAMEBUFFER_EXT', 0x8D40 )
GL_RENDERBUFFER_EXT = constant.Constant( 'GL_RENDERBUFFER_EXT', 0x8D41 )
GL_RENDERBUFFER_WIDTH_EXT = constant.Constant( 'GL_RENDERBUFFER_WIDTH_EXT', 0x8D42 )
GL_RENDERBUFFER_HEIGHT_EXT = constant.Constant( 'GL_RENDERBUFFER_HEIGHT_EXT', 0x8D43 )
GL_RENDERBUFFER_INTERNAL_FORMAT_EXT = constant.Constant( 'GL_RENDERBUFFER_INTERNAL_FORMAT_EXT', 0x8D44 )
GL_STENCIL_INDEX1_EXT = constant.Constant( 'GL_STENCIL_INDEX1_EXT', 0x8D46 )
GL_STENCIL_INDEX4_EXT = constant.Constant( 'GL_STENCIL_INDEX4_EXT', 0x8D47 )
GL_STENCIL_INDEX8_EXT = constant.Constant( 'GL_STENCIL_INDEX8_EXT', 0x8D48 )
GL_STENCIL_INDEX16_EXT = constant.Constant( 'GL_STENCIL_INDEX16_EXT', 0x8D49 )
GL_RENDERBUFFER_RED_SIZE_EXT = constant.Constant( 'GL_RENDERBUFFER_RED_SIZE_EXT', 0x8D50 )
GL_RENDERBUFFER_GREEN_SIZE_EXT = constant.Constant( 'GL_RENDERBUFFER_GREEN_SIZE_EXT', 0x8D51 )
GL_RENDERBUFFER_BLUE_SIZE_EXT = constant.Constant( 'GL_RENDERBUFFER_BLUE_SIZE_EXT', 0x8D52 )
GL_RENDERBUFFER_ALPHA_SIZE_EXT = constant.Constant( 'GL_RENDERBUFFER_ALPHA_SIZE_EXT', 0x8D53 )
GL_RENDERBUFFER_DEPTH_SIZE_EXT = constant.Constant( 'GL_RENDERBUFFER_DEPTH_SIZE_EXT', 0x8D54 )
GL_RENDERBUFFER_STENCIL_SIZE_EXT = constant.Constant( 'GL_RENDERBUFFER_STENCIL_SIZE_EXT', 0x8D55 )
glIsRenderbufferEXT = platform.createExtensionFunction( 
'glIsRenderbufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsRenderbufferEXT(GLuint(renderbuffer)) -> constants.GLboolean',
argNames=('renderbuffer',),
deprecated=_DEPRECATED,
)

glBindRenderbufferEXT = platform.createExtensionFunction( 
'glBindRenderbufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBindRenderbufferEXT(GLenum(target), GLuint(renderbuffer)) -> None',
argNames=('target','renderbuffer',),
deprecated=_DEPRECATED,
)

glDeleteRenderbuffersEXT = platform.createExtensionFunction( 
'glDeleteRenderbuffersEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteRenderbuffersEXT(GLsizei(n), GLuintArray(renderbuffers)) -> None',
argNames=('n','renderbuffers',),
deprecated=_DEPRECATED,
)

glGenRenderbuffersEXT = platform.createExtensionFunction( 
'glGenRenderbuffersEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenRenderbuffersEXT(GLsizei(n), GLuintArray(renderbuffers)) -> None',
argNames=('n','renderbuffers',),
deprecated=_DEPRECATED,
)

glRenderbufferStorageEXT = platform.createExtensionFunction( 
'glRenderbufferStorageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glRenderbufferStorageEXT(GLenum(target), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('target','internalformat','width','height',),
deprecated=_DEPRECATED,
)

glGetRenderbufferParameterivEXT = platform.createExtensionFunction( 
'glGetRenderbufferParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetRenderbufferParameterivEXT(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glIsFramebufferEXT = platform.createExtensionFunction( 
'glIsFramebufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsFramebufferEXT(GLuint(framebuffer)) -> constants.GLboolean',
argNames=('framebuffer',),
deprecated=_DEPRECATED,
)

glBindFramebufferEXT = platform.createExtensionFunction( 
'glBindFramebufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBindFramebufferEXT(GLenum(target), GLuint(framebuffer)) -> None',
argNames=('target','framebuffer',),
deprecated=_DEPRECATED,
)

glDeleteFramebuffersEXT = platform.createExtensionFunction( 
'glDeleteFramebuffersEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteFramebuffersEXT(GLsizei(n), GLuintArray(framebuffers)) -> None',
argNames=('n','framebuffers',),
deprecated=_DEPRECATED,
)

glGenFramebuffersEXT = platform.createExtensionFunction( 
'glGenFramebuffersEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenFramebuffersEXT(GLsizei(n), GLuintArray(framebuffers)) -> None',
argNames=('n','framebuffers',),
deprecated=_DEPRECATED,
)

glCheckFramebufferStatusEXT = platform.createExtensionFunction( 
'glCheckFramebufferStatusEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLenum, 
argTypes=(constants.GLenum,),
doc='glCheckFramebufferStatusEXT(GLenum(target)) -> constants.GLenum',
argNames=('target',),
deprecated=_DEPRECATED,
)

glFramebufferTexture1DEXT = platform.createExtensionFunction( 
'glFramebufferTexture1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glFramebufferTexture1DEXT(GLenum(target), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level)) -> None',
argNames=('target','attachment','textarget','texture','level',),
deprecated=_DEPRECATED,
)

glFramebufferTexture2DEXT = platform.createExtensionFunction( 
'glFramebufferTexture2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glFramebufferTexture2DEXT(GLenum(target), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level)) -> None',
argNames=('target','attachment','textarget','texture','level',),
deprecated=_DEPRECATED,
)

glFramebufferTexture3DEXT = platform.createExtensionFunction( 
'glFramebufferTexture3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,),
doc='glFramebufferTexture3DEXT(GLenum(target), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level), GLint(zoffset)) -> None',
argNames=('target','attachment','textarget','texture','level','zoffset',),
deprecated=_DEPRECATED,
)

glFramebufferRenderbufferEXT = platform.createExtensionFunction( 
'glFramebufferRenderbufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glFramebufferRenderbufferEXT(GLenum(target), GLenum(attachment), GLenum(renderbuffertarget), GLuint(renderbuffer)) -> None',
argNames=('target','attachment','renderbuffertarget','renderbuffer',),
deprecated=_DEPRECATED,
)

glGetFramebufferAttachmentParameterivEXT = platform.createExtensionFunction( 
'glGetFramebufferAttachmentParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetFramebufferAttachmentParameterivEXT(GLenum(target), GLenum(attachment), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','attachment','pname','params',),
deprecated=_DEPRECATED,
)

glGenerateMipmapEXT = platform.createExtensionFunction( 
'glGenerateMipmapEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glGenerateMipmapEXT(GLenum(target)) -> None',
argNames=('target',),
deprecated=_DEPRECATED,
)


def glInitFramebufferObjectEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIS.texture_color_mask

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_texture_color_mask'
_DEPRECATED = False
GL_TEXTURE_COLOR_WRITEMASK_SGIS = constant.Constant( 'GL_TEXTURE_COLOR_WRITEMASK_SGIS', 0x81EF )
glTextureColorMaskSGIS = platform.createExtensionFunction( 
'glTextureColorMaskSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLboolean,constants.GLboolean,constants.GLboolean,constants.GLboolean,),
doc='glTextureColorMaskSGIS(GLboolean(red), GLboolean(green), GLboolean(blue), GLboolean(alpha)) -> None',
argNames=('red','green','blue','alpha',),
deprecated=_DEPRECATED,
)


def glInitTextureColorMaskSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.polynomial_ffd

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_polynomial_ffd'
_DEPRECATED = False
GL_GEOMETRY_DEFORMATION_SGIX = constant.Constant( 'GL_GEOMETRY_DEFORMATION_SGIX', 0x8194 )
GL_TEXTURE_DEFORMATION_SGIX = constant.Constant( 'GL_TEXTURE_DEFORMATION_SGIX', 0x8195 )
GL_DEFORMATIONS_MASK_SGIX = constant.Constant( 'GL_DEFORMATIONS_MASK_SGIX', 0x8196 )
GL_MAX_DEFORMATION_ORDER_SGIX = constant.Constant( 'GL_MAX_DEFORMATION_ORDER_SGIX', 0x8197 )
glDeformationMap3dSGIX = platform.createExtensionFunction( 
'glDeformationMap3dSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLint,constants.GLint,constants.GLdouble,constants.GLdouble,constants.GLint,constants.GLint,constants.GLdouble,constants.GLdouble,constants.GLint,constants.GLint,arrays.GLdoubleArray,),
doc='glDeformationMap3dSGIX(GLenum(target), GLdouble(u1), GLdouble(u2), GLint(ustride), GLint(uorder), GLdouble(v1), GLdouble(v2), GLint(vstride), GLint(vorder), GLdouble(w1), GLdouble(w2), GLint(wstride), GLint(worder), GLdoubleArray(points)) -> None',
argNames=('target','u1','u2','ustride','uorder','v1','v2','vstride','vorder','w1','w2','wstride','worder','points',),
deprecated=_DEPRECATED,
)

glDeformationMap3fSGIX = platform.createExtensionFunction( 
'glDeformationMap3fSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLint,constants.GLint,constants.GLfloat,constants.GLfloat,constants.GLint,constants.GLint,constants.GLfloat,constants.GLfloat,constants.GLint,constants.GLint,arrays.GLfloatArray,),
doc='glDeformationMap3fSGIX(GLenum(target), GLfloat(u1), GLfloat(u2), GLint(ustride), GLint(uorder), GLfloat(v1), GLfloat(v2), GLint(vstride), GLint(vorder), GLfloat(w1), GLfloat(w2), GLint(wstride), GLint(worder), GLfloatArray(points)) -> None',
argNames=('target','u1','u2','ustride','uorder','v1','v2','vstride','vorder','w1','w2','wstride','worder','points',),
deprecated=_DEPRECATED,
)

glDeformSGIX = platform.createExtensionFunction( 
'glDeformSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLbitfield,),
doc='glDeformSGIX(GLbitfield(mask)) -> None',
argNames=('mask',),
deprecated=_DEPRECATED,
)

glLoadIdentityDeformationMapSGIX = platform.createExtensionFunction( 
'glLoadIdentityDeformationMapSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLbitfield,),
doc='glLoadIdentityDeformationMapSGIX(GLbitfield(mask)) -> None',
argNames=('mask',),
deprecated=_DEPRECATED,
)


def glInitPolynomialFfdSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.gpu_program_parameters

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_gpu_program_parameters'
_DEPRECATED = False

glProgramEnvParameters4fvEXT = platform.createExtensionFunction( 
'glProgramEnvParameters4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramEnvParameters4fvEXT(GLenum(target), GLuint(index), GLsizei(count), GLfloatArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)

glProgramLocalParameters4fvEXT = platform.createExtensionFunction( 
'glProgramLocalParameters4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramLocalParameters4fvEXT(GLenum(target), GLuint(index), GLsizei(count), GLfloatArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)


def glInitGpuProgramParametersEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture_compression_latc

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_compression_latc'
_DEPRECATED = False
GL_COMPRESSED_LUMINANCE_LATC1_EXT = constant.Constant( 'GL_COMPRESSED_LUMINANCE_LATC1_EXT', 0x8C70 )
GL_COMPRESSED_SIGNED_LUMINANCE_LATC1_EXT = constant.Constant( 'GL_COMPRESSED_SIGNED_LUMINANCE_LATC1_EXT', 0x8C71 )
GL_COMPRESSED_LUMINANCE_ALPHA_LATC2_EXT = constant.Constant( 'GL_COMPRESSED_LUMINANCE_ALPHA_LATC2_EXT', 0x8C72 )
GL_COMPRESSED_SIGNED_LUMINANCE_ALPHA_LATC2_EXT = constant.Constant( 'GL_COMPRESSED_SIGNED_LUMINANCE_ALPHA_LATC2_EXT', 0x8C73 )


def glInitTextureCompressionLatcEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture_object

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_object'
_DEPRECATED = False
GL_TEXTURE_PRIORITY_EXT = constant.Constant( 'GL_TEXTURE_PRIORITY_EXT', 0x8066 )
GL_TEXTURE_RESIDENT_EXT = constant.Constant( 'GL_TEXTURE_RESIDENT_EXT', 0x8067 )
GL_TEXTURE_1D_BINDING_EXT = constant.Constant( 'GL_TEXTURE_1D_BINDING_EXT', 0x8068 )
glget.addGLGetConstant( GL_TEXTURE_1D_BINDING_EXT, (1,) )
GL_TEXTURE_2D_BINDING_EXT = constant.Constant( 'GL_TEXTURE_2D_BINDING_EXT', 0x8069 )
glget.addGLGetConstant( GL_TEXTURE_2D_BINDING_EXT, (1,) )
GL_TEXTURE_3D_BINDING_EXT = constant.Constant( 'GL_TEXTURE_3D_BINDING_EXT', 0x806A )
glget.addGLGetConstant( GL_TEXTURE_3D_BINDING_EXT, (1,) )
glAreTexturesResidentEXT = platform.createExtensionFunction( 
'glAreTexturesResidentEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLsizei,arrays.GLuintArray,arrays.GLbooleanArray,),
doc='glAreTexturesResidentEXT(GLsizei(n), GLuintArray(textures), GLbooleanArray(residences)) -> constants.GLboolean',
argNames=('n','textures','residences',),
deprecated=_DEPRECATED,
)

glBindTextureEXT = platform.createExtensionFunction( 
'glBindTextureEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBindTextureEXT(GLenum(target), GLuint(texture)) -> None',
argNames=('target','texture',),
deprecated=_DEPRECATED,
)

glDeleteTexturesEXT = platform.createExtensionFunction( 
'glDeleteTexturesEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteTexturesEXT(GLsizei(n), GLuintArray(textures)) -> None',
argNames=('n','textures',),
deprecated=_DEPRECATED,
)

glGenTexturesEXT = platform.createExtensionFunction( 
'glGenTexturesEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenTexturesEXT(GLsizei(n), GLuintArray(textures)) -> None',
argNames=('n','textures',),
deprecated=_DEPRECATED,
)

glIsTextureEXT = platform.createExtensionFunction( 
'glIsTextureEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsTextureEXT(GLuint(texture)) -> constants.GLboolean',
argNames=('texture',),
deprecated=_DEPRECATED,
)

glPrioritizeTexturesEXT = platform.createExtensionFunction( 
'glPrioritizeTexturesEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,arrays.GLclampfArray,),
doc='glPrioritizeTexturesEXT(GLsizei(n), GLuintArray(textures), GLclampfArray(priorities)) -> None',
argNames=('n','textures','priorities',),
deprecated=_DEPRECATED,
)


def glInitTextureObjectEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.copy_buffer

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.copy_buffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism to do an accelerated copy from one
	buffer object to another. This may be useful to load buffer objects
	in a "loading thread" while minimizing cost and synchronization effort
	in the "rendering thread."

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/copy_buffer.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.copy_buffer import *
### END AUTOGENERATED SECTION


'''OpenGL extension SGI.color_table

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGI_color_table'
_DEPRECATED = False
GL_COLOR_TABLE_SGI = constant.Constant( 'GL_COLOR_TABLE_SGI', 0x80D0 )
glget.addGLGetConstant( GL_COLOR_TABLE_SGI, (1,) )
GL_POST_CONVOLUTION_COLOR_TABLE_SGI = constant.Constant( 'GL_POST_CONVOLUTION_COLOR_TABLE_SGI', 0x80D1 )
glget.addGLGetConstant( GL_POST_CONVOLUTION_COLOR_TABLE_SGI, (1,) )
GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI = constant.Constant( 'GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI', 0x80D2 )
glget.addGLGetConstant( GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI, (1,) )
GL_PROXY_COLOR_TABLE_SGI = constant.Constant( 'GL_PROXY_COLOR_TABLE_SGI', 0x80D3 )
GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI = constant.Constant( 'GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI', 0x80D4 )
GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI = constant.Constant( 'GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI', 0x80D5 )
GL_COLOR_TABLE_SCALE_SGI = constant.Constant( 'GL_COLOR_TABLE_SCALE_SGI', 0x80D6 )
GL_COLOR_TABLE_BIAS_SGI = constant.Constant( 'GL_COLOR_TABLE_BIAS_SGI', 0x80D7 )
GL_COLOR_TABLE_FORMAT_SGI = constant.Constant( 'GL_COLOR_TABLE_FORMAT_SGI', 0x80D8 )
GL_COLOR_TABLE_WIDTH_SGI = constant.Constant( 'GL_COLOR_TABLE_WIDTH_SGI', 0x80D9 )
GL_COLOR_TABLE_RED_SIZE_SGI = constant.Constant( 'GL_COLOR_TABLE_RED_SIZE_SGI', 0x80DA )
GL_COLOR_TABLE_GREEN_SIZE_SGI = constant.Constant( 'GL_COLOR_TABLE_GREEN_SIZE_SGI', 0x80DB )
GL_COLOR_TABLE_BLUE_SIZE_SGI = constant.Constant( 'GL_COLOR_TABLE_BLUE_SIZE_SGI', 0x80DC )
GL_COLOR_TABLE_ALPHA_SIZE_SGI = constant.Constant( 'GL_COLOR_TABLE_ALPHA_SIZE_SGI', 0x80DD )
GL_COLOR_TABLE_LUMINANCE_SIZE_SGI = constant.Constant( 'GL_COLOR_TABLE_LUMINANCE_SIZE_SGI', 0x80DE )
GL_COLOR_TABLE_INTENSITY_SIZE_SGI = constant.Constant( 'GL_COLOR_TABLE_INTENSITY_SIZE_SGI', 0x80DF )
glColorTableSGI = platform.createExtensionFunction( 
'glColorTableSGI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glColorTableSGI(GLenum(target), GLenum(internalformat), GLsizei(width), GLenum(format), GLenum(type), c_void_p(table)) -> None',
argNames=('target','internalformat','width','format','type','table',),
deprecated=_DEPRECATED,
)

glColorTableParameterfvSGI = platform.createExtensionFunction( 
'glColorTableParameterfvSGI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glColorTableParameterfvSGI(GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glColorTableParameterivSGI = platform.createExtensionFunction( 
'glColorTableParameterivSGI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glColorTableParameterivSGI(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glCopyColorTableSGI = platform.createExtensionFunction( 
'glCopyColorTableSGI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,),
doc='glCopyColorTableSGI(GLenum(target), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width)) -> None',
argNames=('target','internalformat','x','y','width',),
deprecated=_DEPRECATED,
)

glGetColorTableSGI = platform.createExtensionFunction( 
'glGetColorTableSGI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetColorTableSGI(GLenum(target), GLenum(format), GLenum(type), c_void_p(table)) -> None',
argNames=('target','format','type','table',),
deprecated=_DEPRECATED,
)

glGetColorTableParameterfvSGI = platform.createExtensionFunction( 
'glGetColorTableParameterfvSGI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetColorTableParameterfvSGI(GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetColorTableParameterivSGI = platform.createExtensionFunction( 
'glGetColorTableParameterivSGI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetColorTableParameterivSGI(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)


def glInitColorTableSGI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.gpu_shader4

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_gpu_shader4'
_DEPRECATED = False
GL_SAMPLER_1D_ARRAY_EXT = constant.Constant( 'GL_SAMPLER_1D_ARRAY_EXT', 0x8DC0 )
GL_SAMPLER_2D_ARRAY_EXT = constant.Constant( 'GL_SAMPLER_2D_ARRAY_EXT', 0x8DC1 )
GL_SAMPLER_BUFFER_EXT = constant.Constant( 'GL_SAMPLER_BUFFER_EXT', 0x8DC2 )
GL_SAMPLER_1D_ARRAY_SHADOW_EXT = constant.Constant( 'GL_SAMPLER_1D_ARRAY_SHADOW_EXT', 0x8DC3 )
GL_SAMPLER_2D_ARRAY_SHADOW_EXT = constant.Constant( 'GL_SAMPLER_2D_ARRAY_SHADOW_EXT', 0x8DC4 )
GL_SAMPLER_CUBE_SHADOW_EXT = constant.Constant( 'GL_SAMPLER_CUBE_SHADOW_EXT', 0x8DC5 )
GL_UNSIGNED_INT_VEC2_EXT = constant.Constant( 'GL_UNSIGNED_INT_VEC2_EXT', 0x8DC6 )
GL_UNSIGNED_INT_VEC3_EXT = constant.Constant( 'GL_UNSIGNED_INT_VEC3_EXT', 0x8DC7 )
GL_UNSIGNED_INT_VEC4_EXT = constant.Constant( 'GL_UNSIGNED_INT_VEC4_EXT', 0x8DC8 )
GL_INT_SAMPLER_1D_EXT = constant.Constant( 'GL_INT_SAMPLER_1D_EXT', 0x8DC9 )
GL_INT_SAMPLER_2D_EXT = constant.Constant( 'GL_INT_SAMPLER_2D_EXT', 0x8DCA )
GL_INT_SAMPLER_3D_EXT = constant.Constant( 'GL_INT_SAMPLER_3D_EXT', 0x8DCB )
GL_INT_SAMPLER_CUBE_EXT = constant.Constant( 'GL_INT_SAMPLER_CUBE_EXT', 0x8DCC )
GL_INT_SAMPLER_2D_RECT_EXT = constant.Constant( 'GL_INT_SAMPLER_2D_RECT_EXT', 0x8DCD )
GL_INT_SAMPLER_1D_ARRAY_EXT = constant.Constant( 'GL_INT_SAMPLER_1D_ARRAY_EXT', 0x8DCE )
GL_INT_SAMPLER_2D_ARRAY_EXT = constant.Constant( 'GL_INT_SAMPLER_2D_ARRAY_EXT', 0x8DCF )
GL_INT_SAMPLER_BUFFER_EXT = constant.Constant( 'GL_INT_SAMPLER_BUFFER_EXT', 0x8DD0 )
GL_UNSIGNED_INT_SAMPLER_1D_EXT = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_1D_EXT', 0x8DD1 )
GL_UNSIGNED_INT_SAMPLER_2D_EXT = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_2D_EXT', 0x8DD2 )
GL_UNSIGNED_INT_SAMPLER_3D_EXT = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_3D_EXT', 0x8DD3 )
GL_UNSIGNED_INT_SAMPLER_CUBE_EXT = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_CUBE_EXT', 0x8DD4 )
GL_UNSIGNED_INT_SAMPLER_2D_RECT_EXT = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_2D_RECT_EXT', 0x8DD5 )
GL_UNSIGNED_INT_SAMPLER_1D_ARRAY_EXT = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_1D_ARRAY_EXT', 0x8DD6 )
GL_UNSIGNED_INT_SAMPLER_2D_ARRAY_EXT = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_2D_ARRAY_EXT', 0x8DD7 )
GL_UNSIGNED_INT_SAMPLER_BUFFER_EXT = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_BUFFER_EXT', 0x8DD8 )
glGetUniformuivEXT = platform.createExtensionFunction( 
'glGetUniformuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,arrays.GLuintArray,),
doc='glGetUniformuivEXT(GLuint(program), GLint(location), GLuintArray(params)) -> None',
argNames=('program','location','params',),
deprecated=_DEPRECATED,
)

glBindFragDataLocationEXT = platform.createExtensionFunction( 
'glBindFragDataLocationEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,arrays.GLcharArray,),
doc='glBindFragDataLocationEXT(GLuint(program), GLuint(color), GLcharArray(name)) -> None',
argNames=('program','color','name',),
deprecated=_DEPRECATED,
)

glGetFragDataLocationEXT = platform.createExtensionFunction( 
'glGetFragDataLocationEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLint, 
argTypes=(constants.GLuint,arrays.GLcharArray,),
doc='glGetFragDataLocationEXT(GLuint(program), GLcharArray(name)) -> constants.GLint',
argNames=('program','name',),
deprecated=_DEPRECATED,
)

glUniform1uiEXT = platform.createExtensionFunction( 
'glUniform1uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLuint,),
doc='glUniform1uiEXT(GLint(location), GLuint(v0)) -> None',
argNames=('location','v0',),
deprecated=_DEPRECATED,
)

glUniform2uiEXT = platform.createExtensionFunction( 
'glUniform2uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLuint,constants.GLuint,),
doc='glUniform2uiEXT(GLint(location), GLuint(v0), GLuint(v1)) -> None',
argNames=('location','v0','v1',),
deprecated=_DEPRECATED,
)

glUniform3uiEXT = platform.createExtensionFunction( 
'glUniform3uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glUniform3uiEXT(GLint(location), GLuint(v0), GLuint(v1), GLuint(v2)) -> None',
argNames=('location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glUniform4uiEXT = platform.createExtensionFunction( 
'glUniform4uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glUniform4uiEXT(GLint(location), GLuint(v0), GLuint(v1), GLuint(v2), GLuint(v3)) -> None',
argNames=('location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glUniform1uivEXT = platform.createExtensionFunction( 
'glUniform1uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glUniform1uivEXT(GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform2uivEXT = platform.createExtensionFunction( 
'glUniform2uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glUniform2uivEXT(GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform3uivEXT = platform.createExtensionFunction( 
'glUniform3uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glUniform3uivEXT(GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform4uivEXT = platform.createExtensionFunction( 
'glUniform4uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glUniform4uivEXT(GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)


def glInitGpuShader4EXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.tag_sample_buffer

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.tag_sample_buffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	The extensions defines a special purpose fast multisample clear.
	This clear can be used with some restrictions as a significantly
	faster alternative to Clear(DEPTH_BUFFER_BIT).
	
	The extension is based on the RealityEngine architecture and will
	probably never be supported by any other architecture.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/tag_sample_buffer.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.SGIX.tag_sample_buffer import *
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.polygon_offset

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_polygon_offset'
_DEPRECATED = False
GL_POLYGON_OFFSET_EXT = constant.Constant( 'GL_POLYGON_OFFSET_EXT', 0x8037 )
glget.addGLGetConstant( GL_POLYGON_OFFSET_EXT, (1,) )
GL_POLYGON_OFFSET_FACTOR_EXT = constant.Constant( 'GL_POLYGON_OFFSET_FACTOR_EXT', 0x8038 )
glget.addGLGetConstant( GL_POLYGON_OFFSET_FACTOR_EXT, (1,) )
GL_POLYGON_OFFSET_BIAS_EXT = constant.Constant( 'GL_POLYGON_OFFSET_BIAS_EXT', 0x8039 )
glget.addGLGetConstant( GL_POLYGON_OFFSET_BIAS_EXT, (1,) )
glPolygonOffsetEXT = platform.createExtensionFunction( 
'glPolygonOffsetEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,),
doc='glPolygonOffsetEXT(GLfloat(factor), GLfloat(bias)) -> None',
argNames=('factor','bias',),
deprecated=_DEPRECATED,
)


def glInitPolygonOffsetEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.draw_buffers_blend

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_draw_buffers_blend'
_DEPRECATED = False

glBlendEquationi = platform.createExtensionFunction( 
'glBlendEquationi',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glBlendEquationi(GLuint(buf), GLenum(mode)) -> None',
argNames=('buf','mode',),
deprecated=_DEPRECATED,
)

glBlendEquationSeparatei = platform.createExtensionFunction( 
'glBlendEquationSeparatei',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,),
doc='glBlendEquationSeparatei(GLuint(buf), GLenum(modeRGB), GLenum(modeAlpha)) -> None',
argNames=('buf','modeRGB','modeAlpha',),
deprecated=_DEPRECATED,
)

glBlendFunci = platform.createExtensionFunction( 
'glBlendFunci',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,),
doc='glBlendFunci(GLuint(buf), GLenum(src), GLenum(dst)) -> None',
argNames=('buf','src','dst',),
deprecated=_DEPRECATED,
)

glBlendFuncSeparatei = platform.createExtensionFunction( 
'glBlendFuncSeparatei',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,),
doc='glBlendFuncSeparatei(GLuint(buf), GLenum(srcRGB), GLenum(dstRGB), GLenum(srcAlpha), GLenum(dstAlpha)) -> None',
argNames=('buf','srcRGB','dstRGB','srcAlpha','dstAlpha',),
deprecated=_DEPRECATED,
)


def glInitDrawBuffersBlendARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
